@@ -239,7 +239,7 @@ get_name_for_file (char *filename, char **subsect)
 
   /* We assume, like reasonable people, that man pages
    * have one of the forms:
-   * manname.sect.{gz,bz,bz2}
+   * manname.sect.{gz,bz,bz2,lzma}
    * manname.sect
    * If it doesn't, things will probably break but we return
    * our "best guess" (i.e. everything up to the suffix)
@@ -250,6 +250,9 @@ get_name_for_file (char *filename, char **subsect)
     if (!suffix) {
       suffix = strrstr(filename, ".bz");
     }
+      if (!suffix) {
+        suffix = strrstr(filename, ".lzma");
+      }
   }
   if (suffix)
     cut = rrn_strndup (filename, suffix-filename);
